searchData={"items":[{"type":"module","title":"PromptVault","doc":"PromptVault provides an immutable, token-aware context management system for LLM prompts.\n\nThe main entry point is `new/1` to create a new context, followed by functions\nto add messages, manage tokens, render templates, and compact message history.","ref":"PromptVault.html"},{"type":"module","title":"Example - PromptVault","doc":"iex> PromptVault.new(model: :gpt4, temperature: 0.7)\n    %PromptVault.Context{model: :gpt4, temperature: 0.7, messages: [], token_count: 0}","ref":"PromptVault.html#module-example"},{"type":"function","title":"PromptVault.add_media/4","doc":"Adds a media message to the context.","ref":"PromptVault.html#add_media/4"},{"type":"function","title":"Parameters - PromptVault.add_media/4","doc":"- `context` - The PromptVault context\n- `mime_type` - MIME type of the media (string)\n- `url` - URL or data URI of the media (string)\n- `opts` - Options including `:size`, `:template`, `:engine`, `:assigns`, `:raw`","ref":"PromptVault.html#add_media/4-parameters"},{"type":"function","title":"Examples - PromptVault.add_media/4","doc":"iex> context = PromptVault.new()\n    iex> {:ok, updated} = PromptVault.add_media(context, \"image/jpeg\", \"https://example.com/img.jpg\")\n    iex> length(updated.messages)\n    1","ref":"PromptVault.html#add_media/4-examples"},{"type":"function","title":"PromptVault.add_message/4","doc":"Adds a message to the context.","ref":"PromptVault.html#add_message/4"},{"type":"function","title":"Parameters - PromptVault.add_message/4","doc":"- `context` - The PromptVault context\n- `role` - Message role (`:system`, `:user`, or `:assistant`)\n- `raw` - The raw message content\n- `opts` - Options including `:template`, `:engine`, `:assigns`","ref":"PromptVault.html#add_message/4-parameters"},{"type":"function","title":"Examples - PromptVault.add_message/4","doc":"iex> context = PromptVault.new()\n    iex> {:ok, updated} = PromptVault.add_message(context, :user, \"Hello\")\n    iex> length(updated.messages)\n    1","ref":"PromptVault.html#add_message/4-examples"},{"type":"function","title":"PromptVault.add_tool_call/5","doc":"Adds a tool call message to the context.","ref":"PromptVault.html#add_tool_call/5"},{"type":"function","title":"Parameters - PromptVault.add_tool_call/5","doc":"- `context` - The PromptVault context\n- `tool` - Tool name (atom or string)\n- `args` - Tool arguments (map)\n- `response_schema` - Expected response schema (map or string)\n- `opts` - Options including `:template`, `:engine`, `:assigns`, `:raw`","ref":"PromptVault.html#add_tool_call/5-parameters"},{"type":"function","title":"Examples - PromptVault.add_tool_call/5","doc":"iex> context = PromptVault.new()\n    iex> {:ok, updated} = PromptVault.add_tool_call(context, :weather, %{city: \"NYC\"}, nil)\n    iex> length(updated.messages)\n    1","ref":"PromptVault.html#add_tool_call/5-examples"},{"type":"function","title":"PromptVault.compact/3","doc":"Compacts the context using the specified or configured compaction strategy.","ref":"PromptVault.html#compact/3"},{"type":"function","title":"Parameters - PromptVault.compact/3","doc":"- `context` - The PromptVault context\n- `strategy` - Compaction strategy module or nil to use configured strategy\n- `opts` - Options to pass to the compaction strategy","ref":"PromptVault.html#compact/3-parameters"},{"type":"function","title":"Examples - PromptVault.compact/3","doc":"iex> summarizer = fn msgs -> \"Summary of \" <> Integer.to_string(length(msgs)) <> \" messages\" end\n    iex> context = PromptVault.new()\n    iex> {:ok, context} = PromptVault.add_message(context, :user, \"Hello\")\n    iex> {:ok, compacted} = PromptVault.compact(context, PromptVault.Compaction.SummarizeHistory, summarizer: summarizer)\n    iex> length(compacted.messages)\n    1","ref":"PromptVault.html#compact/3-examples"},{"type":"function","title":"PromptVault.count_and_cache_tokens/1","doc":"Counts tokens and returns an updated context with the cached count.","ref":"PromptVault.html#count_and_cache_tokens/1"},{"type":"function","title":"Examples - PromptVault.count_and_cache_tokens/1","doc":"iex> context = PromptVault.new(token_counter: PromptVault.TokenCounter.PretendTokenizer)\n    iex> {:ok, context} = PromptVault.add_message(context, :user, \"Hello\")\n    iex> {:ok, updated_context} = PromptVault.count_and_cache_tokens(context)\n    iex> updated_context.token_count >= 0\n    true","ref":"PromptVault.html#count_and_cache_tokens/1-examples"},{"type":"function","title":"PromptVault.new/1","doc":"Creates a new PromptVault context with the given options.","ref":"PromptVault.html#new/1"},{"type":"function","title":"Options - PromptVault.new/1","doc":"- `:model` - The LLM model to use (atom or string)\n- `:temperature` - Temperature setting for the model\n- `:max_tokens` - Maximum tokens for the model\n- `:token_counter` - Module implementing TokenCounter behaviour\n- `:compaction_strategy` - Module or {module, opts} for compaction","ref":"PromptVault.html#new/1-options"},{"type":"function","title":"Examples - PromptVault.new/1","doc":"iex> PromptVault.new(model: :gpt4, temperature: 0.7)\n    %PromptVault.Context{model: :gpt4, temperature: 0.7, messages: [], token_count: 0}","ref":"PromptVault.html#new/1-examples"},{"type":"function","title":"PromptVault.put_model/2","doc":"Updates the model for the given context.","ref":"PromptVault.html#put_model/2"},{"type":"function","title":"Examples - PromptVault.put_model/2","doc":"iex> PromptVault.new() |> PromptVault.put_model(:gpt4)\n    %PromptVault.Context{model: :gpt4, messages: [], token_count: 0}","ref":"PromptVault.html#put_model/2-examples"},{"type":"function","title":"PromptVault.put_opts/2","doc":"Updates multiple options for the given context.\n\nAccepts the same options as `new/1`.","ref":"PromptVault.html#put_opts/2"},{"type":"function","title":"Examples - PromptVault.put_opts/2","doc":"iex> PromptVault.new() |> PromptVault.put_opts(temperature: 0.5, max_tokens: 1000)\n    %PromptVault.Context{temperature: 0.5, max_tokens: 1000, messages: [], token_count: 0}","ref":"PromptVault.html#put_opts/2-examples"},{"type":"function","title":"PromptVault.render/2","doc":"Renders all messages in the context to iodata.\n\nProcesses each message in order, calling their rendered/2 callbacks\nwith the message's assigns merged with any provided assigns.","ref":"PromptVault.html#render/2"},{"type":"function","title":"Examples - PromptVault.render/2","doc":"iex> context = PromptVault.new()\n    iex> {:ok, context} = PromptVault.add_message(context, :user, \"Hello\")\n    iex> rendered = PromptVault.render(context)\n    iex> is_binary(IO.iodata_to_binary(rendered))\n    true","ref":"PromptVault.html#render/2-examples"},{"type":"function","title":"PromptVault.token_count/1","doc":"Counts tokens in the context using the configured token counter.\n\nReturns the cached token count if available, otherwise renders all messages\nand counts tokens.","ref":"PromptVault.html#token_count/1"},{"type":"function","title":"Examples - PromptVault.token_count/1","doc":"iex> context = PromptVault.new(token_counter: PromptVault.TokenCounter.PretendTokenizer)\n    iex> {:ok, context} = PromptVault.add_message(context, :user, \"Hello\")\n    iex> {:ok, count} = PromptVault.token_count(context)\n    iex> count >= 0\n    true","ref":"PromptVault.html#token_count/1-examples"},{"type":"behaviour","title":"PromptVault.Compaction","doc":"Behaviour for compaction strategy implementations.\n\nCompaction strategies are used to reduce the number of messages in a context\nwhile preserving important information, typically to manage token limits.","ref":"PromptVault.Compaction.html"},{"type":"callback","title":"PromptVault.Compaction.compact/2","doc":"Compacts the given context using the strategy's algorithm.\n\nReturns a new context with fewer messages, or an error if compaction fails.","ref":"PromptVault.Compaction.html#c:compact/2"},{"type":"type","title":"PromptVault.Compaction.t/0","doc":"","ref":"PromptVault.Compaction.html#t:t/0"},{"type":"module","title":"PromptVault.Context","doc":"The core immutable context structure for PromptVault.\n\nA Context holds all the state needed for managing LLM prompts including\nmessages, model configuration, token counting, and compaction strategies.","ref":"PromptVault.Context.html"},{"type":"type","title":"PromptVault.Context.compaction_strategy/0","doc":"","ref":"PromptVault.Context.html#t:compaction_strategy/0"},{"type":"type","title":"PromptVault.Context.message/0","doc":"","ref":"PromptVault.Context.html#t:message/0"},{"type":"opaque","title":"PromptVault.Context.t/0","doc":"","ref":"PromptVault.Context.html#t:t/0"},{"type":"type","title":"PromptVault.Context.token_counter/0","doc":"","ref":"PromptVault.Context.html#t:token_counter/0"},{"type":"behaviour","title":"PromptVault.Message","doc":"Behaviour for message types in PromptVault.\n\nAll message types must implement this behaviour to provide consistent\naccess to role, raw content, rendered output, and template engine information.","ref":"PromptVault.Message.html"},{"type":"callback","title":"PromptVault.Message.raw/1","doc":"Returns the raw content of the message.","ref":"PromptVault.Message.html#c:raw/1"},{"type":"callback","title":"PromptVault.Message.rendered/2","doc":"Renders the message with the given assigns, returning iodata.","ref":"PromptVault.Message.html#c:rendered/2"},{"type":"callback","title":"PromptVault.Message.role/1","doc":"Returns the role of the message as an atom.","ref":"PromptVault.Message.html#c:role/1"},{"type":"type","title":"PromptVault.Message.t/0","doc":"","ref":"PromptVault.Message.html#t:t/0"},{"type":"callback","title":"PromptVault.Message.template_engine/1","doc":"Returns the template engine used by this message, or nil if none.","ref":"PromptVault.Message.html#c:template_engine/1"},{"type":"behaviour","title":"PromptVault.TemplateEngine","doc":"Behaviour for template engine implementations.\n\nTemplate engines are responsible for rendering templates with assigns.\nThey support different template sources like inline strings, files, and modules.","ref":"PromptVault.TemplateEngine.html"},{"type":"callback","title":"PromptVault.TemplateEngine.render/2","doc":"Renders a template with the given assigns.\n\nTemplate sources can be:\n- `{:inline, string}` - Inline template string\n- `{:file, path}` - Template file path\n- `{:module, module}` - Module with render/1 function","ref":"PromptVault.TemplateEngine.html#c:render/2"},{"type":"type","title":"PromptVault.TemplateEngine.t/0","doc":"","ref":"PromptVault.TemplateEngine.html#t:t/0"},{"type":"behaviour","title":"PromptVault.TokenCounter","doc":"Behaviour for token counting implementations.\n\nToken counters are responsible for counting tokens in content for specific models.\nImplementations should handle both atom and string model names.","ref":"PromptVault.TokenCounter.html"},{"type":"callback","title":"PromptVault.TokenCounter.count/2","doc":"Counts tokens in the given content for the specified model.","ref":"PromptVault.TokenCounter.html#c:count/2"},{"type":"type","title":"PromptVault.TokenCounter.t/0","doc":"","ref":"PromptVault.TokenCounter.html#t:t/0"},{"type":"module","title":"PromptVault.Message.MediaMessage","doc":"A message representing media content like images, audio, or video.\n\nMedia messages always have the role `:media` and contain MIME type,\nURL information, and optional size metadata.","ref":"PromptVault.Message.MediaMessage.html"},{"type":"type","title":"PromptVault.Message.MediaMessage.t/0","doc":"","ref":"PromptVault.Message.MediaMessage.html#t:t/0"},{"type":"module","title":"PromptVault.Message.PromptMessage","doc":"A basic prompt message with role, content, and optional template processing.\n\nThis is the primary message type for user, assistant, and system messages.","ref":"PromptVault.Message.PromptMessage.html"},{"type":"type","title":"PromptVault.Message.PromptMessage.t/0","doc":"","ref":"PromptVault.Message.PromptMessage.html#t:t/0"},{"type":"module","title":"PromptVault.Message.ToolCallMessage","doc":"A message representing a tool or function call with arguments and response schema.\n\nTool call messages always have the role `:tool` and contain information about\nthe tool being called, its arguments, and expected response format.","ref":"PromptVault.Message.ToolCallMessage.html"},{"type":"type","title":"PromptVault.Message.ToolCallMessage.t/0","doc":"","ref":"PromptVault.Message.ToolCallMessage.html#t:t/0"},{"type":"module","title":"PromptVault.TemplateEngine.EExEngine","doc":"EEx template engine implementation for PromptVault.\n\nSupports three template source formats:\n- `{:inline, template_string}` - Inline EEx template\n- `{:file, file_path}` - Template from file\n- `{:module, module}` - Template from module's render/1 function","ref":"PromptVault.TemplateEngine.EExEngine.html"},{"type":"module","title":"PromptVault.TemplateEngine.LiquidEngine","doc":"Liquid template engine implementation for PromptVault using Solid.\n\nThis engine requires the optional `solid` dependency to be available.\nIf not available, all render calls will return an error.\n\nSupports the same template source formats as EExEngine:\n- `{:inline, template_string}` - Inline Liquid template\n- `{:file, file_path}` - Template from file\n- `{:module, module}` - Template from module's render/1 function","ref":"PromptVault.TemplateEngine.LiquidEngine.html"},{"type":"module","title":"PromptVault.TokenCounter.PretendTokenizer","doc":"Token counter implementation using the fnord library.\n\nThis implementation uses AI.PretendTokenizer.guesstimate_tokens/1 from the fnord package\nto provide token count estimates.","ref":"PromptVault.TokenCounter.PretendTokenizer.html"},{"type":"module","title":"PromptVault.Compaction.SummarizeHistory","doc":"Compaction strategy that summarizes message history.\n\nThis strategy preserves the first system message (if any) and replaces\nall other messages with a single assistant message containing a summary\nof the conversation history.","ref":"PromptVault.Compaction.SummarizeHistory.html"},{"type":"module","title":"Usage - PromptVault.Compaction.SummarizeHistory","doc":"summarizer = fn messages ->\n      \"Summary of conversation with \" <> Integer.to_string(length(messages)) <> \" messages\"\n    end\n\n    context = PromptVault.new(compaction_strategy: __MODULE__)\n    {:ok, compacted} = PromptVault.compact(context, nil, summarizer: summarizer)","ref":"PromptVault.Compaction.SummarizeHistory.html#module-usage"},{"type":"extras","title":"Home","doc":"# PromptVault\n\n[![Hex.pm](https://img.shields.io/hexpm/v/prompt_vault.svg)](https://hex.pm/packages/prompt_vault)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/prompt_vault/)\n[![CI](https://github.com/ElixirMentor/prompt_vault/workflows/CI/badge.svg)](https://github.com/ElixirMentor/prompt_vault/actions)\n[![Coverage Status](https://img.shields.io/coveralls/github/ElixirMentor/prompt_vault.svg)](https://coveralls.io/github/ElixirMentor/prompt_vault)\n\nA toolkit for managing and processing prompts with context, templates, and token counting for LLM applications.\n\nPromptVault provides an immutable, token-aware context management system that helps you build robust LLM prompt pipelines with features like:\n\n- **Context Management**: Immutable context with message history\n- **Token Counting**: Built-in token counting with pluggable tokenizers\n- **Template Support**: EEx and Liquid template engines\n- **Message Types**: Support for text, tool calls, and media messages\n- **Compaction Strategies**: Automatic context compaction when approaching token limits\n- **Type Safety**: Full Elixir typespecs and documentation","ref":"readme.html"},{"type":"extras","title":"Installation - Home","doc":"Add `prompt_vault` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:prompt_vault, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Quick Start - Home","doc":"```elixir\n# Create a new context\ncontext = PromptVault.new(\n  model: :gpt4,\n  temperature: 0.7,\n  token_counter: PromptVault.TokenCounter.PretendTokenizer\n)\n\n# Add messages\n{:ok, context} = PromptVault.add_message(context, :system, \"You are a helpful assistant\")\n{:ok, context} = PromptVault.add_message(context, :user, \"Hello!\")\n\n# Count tokens\n{:ok, token_count} = PromptVault.token_count(context)\n\n# Render to final prompt\nrendered = PromptVault.render(context)\n```","ref":"readme.html#quick-start"},{"type":"extras","title":"Features - Home","doc":"","ref":"readme.html#features"},{"type":"extras","title":"Message Types - Home","doc":"**Text Messages**\n```elixir\n{:ok, context} = PromptVault.add_message(context, :user, \"What's the weather like?\")\n```\n\n**Tool Calls**\n```elixir\n{:ok, context} = PromptVault.add_tool_call(\n  context, \n  :get_weather, \n  %{city: \"New York\"}, \n  %{type: \"object\", properties: %{temperature: %{type: \"number\"}}}\n)\n```\n\n**Media Messages**\n```elixir\n{:ok, context} = PromptVault.add_media(\n  context, \n  \"image/jpeg\", \n  \"https://example.com/image.jpg\"\n)\n```","ref":"readme.html#message-types"},{"type":"extras","title":"Templates - Home","doc":"Use templates with assigns for dynamic content:\n\n```elixir\n{:ok, context} = PromptVault.add_message(\n  context, \n  :user, \n  \"Hello <%= @name %>!\", \n  template: true, \n  assigns: %{name: \"World\"}\n)\n```","ref":"readme.html#templates"},{"type":"extras","title":"Context Compaction - Home","doc":"Automatically compact context when approaching token limits:\n\n```elixir\ncontext = PromptVault.new(\n  compaction_strategy: PromptVault.Compaction.SummarizeHistory,\n  token_counter: PromptVault.TokenCounter.PretendTokenizer\n)\n\n{:ok, compacted_context} = PromptVault.compact(context)\n```","ref":"readme.html#context-compaction"},{"type":"extras","title":"Configuration - Home","doc":"Configure your context with various options:\n\n```elixir\ncontext = PromptVault.new(\n  model: :gpt4,                    # LLM model\n  temperature: 0.7,                # Model temperature\n  max_tokens: 4000,                # Token limit\n  token_counter: MyTokenCounter,   # Custom token counter\n  compaction_strategy: MyStrategy  # Custom compaction strategy\n)\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Documentation - Home","doc":"Full documentation is available at [https://hexdocs.pm/prompt_vault](https://hexdocs.pm/prompt_vault).","ref":"readme.html#documentation"},{"type":"extras","title":"License - Home","doc":"MIT License. See [LICENSE.md](LICENSE.md) for details.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}